### Installation
This module is used for sentiment analysis of a text. The module prints 'pos' for text having positive sentiments while 'neg' for text having negative sentiments. It is built on top of nltk and basic python modules.   

Usages: python-sentiment "InputText" 
	
```sh
$ pip install python-sentiment
$ python-sentiment "The movie was awesome"
```
### License
MIT
### Author
Sahil Ahuja
